iac_route_tracker_ext library

Classes

IacRouteHistoryEntry
A single navigation event recorded in the route history.
IacRouteStackEntry
A single entry in the live route stack.
IacRouteTrackerExtension
An InAppConsoleExtension that displays the current navigation state, including the current and previous deep link and the full route stack.
IacRouteTrackerNavigationObserver
A RouteObserver that tracks navigation history and the live route stack as the user navigates through the app using Flutter Navigator 1.0.